[Xfce4-commits] <thunar:master> Permanently delete files if one of them cannot be trashed (bug #6748).

Jannis Pohlmann noreply at xfce.org
Sun Nov 14 02:16:01 CET 2010


Updating branch refs/heads/master
         to a7f2bb4c9ce3b3a11e1d8348f1ef802250c7a366 (commit)
       from cbff382141b03cd632e5e3d1e0500aa139322437 (commit)

commit a7f2bb4c9ce3b3a11e1d8348f1ef802250c7a366
Author: Jannis Pohlmann <jannis at xfce.org>
Date:   Sun Nov 14 02:13:26 2010 +0100

    Permanently delete files if one of them cannot be trashed (bug #6748).

 NEWS                        |    2 ++
 thunar/thunar-application.c |   12 ++++++------
 2 files changed, 8 insertions(+), 6 deletions(-)

diff --git a/NEWS b/NEWS
index 819adc6..647b572 100644
--- a/NEWS
+++ b/NEWS
@@ -9,6 +9,8 @@
   directory instead of home (bug #3451).
 - Print an error if thunar-settings fails to contact the file manager
   service (bug #6547).
+- Permanently delete files if at least one of them cannot be trashed
+  (bug #6748).
 
 1.1.4
 =====
diff --git a/thunar/thunar-application.c b/thunar/thunar-application.c
index 2419154..c65d5b2 100644
--- a/thunar/thunar-application.c
+++ b/thunar/thunar-application.c
@@ -732,19 +732,19 @@ thunar_application_get_daemon (ThunarApplication *application)
 /**
  * thunar_application_set_daemon:
  * @application : a #ThunarApplication.
  * @daemon      : %TRUE to set @application into daemon mode.
  *
  * If @daemon is %TRUE, @application will be set into daemon mode.
  **/
 void
 thunar_application_set_daemon (ThunarApplication *application,
-                               gboolean           daemon)
+                               gboolean           daemonize)
 {
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
-  if (application->daemon != daemon)
+  if (application->daemon != daemonize)
     {
-      application->daemon = daemon;
+      application->daemon = daemonize;
       g_object_notify (G_OBJECT (application), "daemon");
     }
 }
@@ -1656,8 +1656,8 @@ thunar_application_unlink_files (ThunarApplication *application,
       path_list = thunar_g_file_list_prepend (path_list, thunar_file_get_file (lp->data));
 
       /* permanently delete if at least one of the file is not a local 
-       * file (e.g. resides in the trash) */
-      if (!thunar_file_is_local (lp->data))
+       * file (e.g. resides in the trash) or cannot be trashed */
+      if (!thunar_file_is_local (lp->data) || !thunar_file_can_be_trashed (lp->data))
         permanently = TRUE;
     }
 
@@ -732,19 +732,19 @@ thunar_application_get_daemon (ThunarApplication *application)
  * thunar_application_set_daemon:
  * @application : a #ThunarApplication.
- * @daemon      : %TRUE to set @application into daemon mode.
+ * @daemonize   : %TRUE to set @application into daemon mode.
  *
  * If @daemon is %TRUE, @application will be set into daemon mode.



More information about the Xfce4-commits mailing list